Random field-element selection.
[u/mdw/catacomb] / ec.h
diff --git a/ec.h b/ec.h
index 476d898..680bf9c 100644 (file)
--- a/ec.h
+++ b/ec.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: ec.h,v 1.4.4.2 2004/03/20 00:13:31 mdw Exp $
+ * $Id: ec.h,v 1.6 2004/03/22 02:19:10 mdw Exp $
  *
  * Elliptic curve definitions
  *
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: ec.h,v $
+ * Revision 1.6  2004/03/22 02:19:10  mdw
+ * Rationalise the sliding-window threshold.  Drop guarantee that right
+ * arguments to EC @add@ are canonical, and fix up projective implementations
+ * to cope.
+ *
+ * Revision 1.5  2004/03/21 22:52:06  mdw
+ * Merge and close elliptic curve branch.
+ *
+ * Revision 1.4.4.3  2004/03/21 22:39:46  mdw
+ * Elliptic curves on binary fields work.
+ *
  * Revision 1.4.4.2  2004/03/20 00:13:31  mdw
  * Projective coordinates for prime curves
  *
@@ -89,9 +100,12 @@ typedef struct ec_mulfactor {
 /* --- Elliptic curve operations --- *
  *
  * All operations (apart from @destroy@ and @in@) are guaranteed to be
- * performed on internal representations of points.  Moreover, the second
- * argument to @add@ and @mul@ is guaranteed to be the output of @in@ or
- * @fix@.
+ * performed on internal representations of points.
+ *
+ * (Historical note.  We used to guarantee that the second to @add@ and @mul@
+ * was the output of @in@ or @fix@, but this canonification turned out to
+ * make the precomputation in @ec_exp@ too slow.  Projective implementations
+ * must therefore cope with a pair of arbitrary points.)
  */
 
 typedef struct ec_ops {
@@ -419,18 +433,20 @@ extern void ec_destroycurve(ec_curve */*c*/);
 extern ec_curve *ec_prime(field */*f*/, mp */*a*/, mp */*b*/);
 extern ec_curve *ec_primeproj(field */*f*/, mp */*a*/, mp */*b*/);
 
-/* --- @ec_bin@ --- *
+/* --- @ec_bin@, @ec_binproj@ --- *
  *
  * Arguments:  @field *f@ = the underlying field for this elliptic curve
  *             @mp *a, *b@ = the coefficients for this curve
  *
  * Returns:    A pointer to the curve.
  *
* Use:                Creates a curve structure for a non-supersingular elliptic
*             curve defined over a binary field.
  */
 
 extern ec_curve *ec_bin(field */*f*/, mp */*a*/, mp */*b*/);
+extern ec_curve *ec_binproj(field */*f*/, mp */*a*/, mp */*b*/);
 
 /*----- That's all, folks -------------------------------------------------*/
@@ -419,18 +433,20 @@ extern void ec_destroycurve(ec_curve */*c*/);
  * Returns:    A pointer to the curve.
  *
- * Use:                Creates a curve structure for a non-supersingular elliptic
- *             curve defined over a binary field.
+ * Use:                Creates a curve structure for an elliptic curve defined over
+ *             a binary field.  The @binproj@ variant uses projective
+ *             coordinates, which can be a win.
  */
 